@@ -3,28 +3,23 @@
 import logging
 import re
 import shlex
-from concurrent.futures import (
-    Executor,
-    ProcessPoolExecutor,
-    ThreadPoolExecutor,
-)
 from enum import IntEnum
-from typing import Callable, Iterable, Mapping, Optional, Tuple, Union
+from typing import Iterable, Mapping, Optional, Tuple, Union, Any
+
+from click import Choice
+from click import Context
+from click import BadParameter
+from click import Parameter
+from click import ParamType
+from click import Option
+from click import STRING
 
-from click import (
-    Choice,
-    Context,
-    BadParameter,
-    Parameter,
-    ParamType,
-    Option,
-    STRING,
-)
 from yaml import safe_load
 from yaml.error import MarkedYAMLError
 
 from preacher.compilation.argument import Arguments
 from preacher.core.status import Status
+from .executor import ExecutorFactory, PROCESS_POOL_FACTORY, THREAD_POOL_FACTORY
 
 
 class Level(IntEnum):
@@ -38,9 +33,9 @@ class Level(IntEnum):
 
 
 _LEVEL_MAP: Mapping[str, Level] = {str(level): level for level in Level}
-_CONCURRENT_EXECUTOR_FACTORY_MAP: Mapping[str, Callable[[int], Executor]] = {
-    'process': ProcessPoolExecutor,
-    'thread': ThreadPoolExecutor,
+_CONCURRENT_EXECUTOR_FACTORY_MAP: Mapping[str, ExecutorFactory] = {
+    'process': PROCESS_POOL_FACTORY,
+    'thread': THREAD_POOL_FACTORY,
 }
 
 
@@ -59,19 +54,18 @@ class ArgumentType(ParamType):
 
 class LevelType(ParamType):
 
-    _choice = Choice(
-        tuple(item.name.lower() for item in Status),
-        case_sensitive=False,
-    )
+    _choice = Choice(tuple(item.name.lower() for item in Status), case_sensitive=False)
     name = _choice.name
 
-    def get_metavar(self, param):
+    def get_metavar(self, param: Parameter) -> str:
         return self._choice.get_metavar(param)
 
-    def get_missing_message(self, param):
+    def get_missing_message(self, param: Parameter) -> str:
         return self._choice.get_missing_message(param)
 
-    def convert(self, value, param, ctx):
+    def convert(self, value: Any, param: Optional[Parameter], ctx: Optional[Context]) -> Status:
+        if isinstance(value, Status):
+            return value
         key = self._choice.convert(value, param, ctx).lower()
         return next(item for item in Status if item.name.lower() == key)
 
@@ -90,7 +84,14 @@ class ExecutorFactoryType(ParamType):
     def get_missing_message(self, param):
         return self._choice.get_missing_message(param)
 
-    def convert(self, value, param, ctx):
+    def convert(
+        self,
+        value: Any,
+        param: Optional[Parameter],
+        ctx: Optional[Context],
+    ) -> ExecutorFactory:
+        if isinstance(value, ExecutorFactory):
+            return value
         key = self._choice.convert(value, param, ctx)
         return _CONCURRENT_EXECUTOR_FACTORY_MAP[key.lower()]
 
